@@ -17,17 +17,19 @@ from .prediction_algorithms import PredictionImpossible
 from .prediction_algorithms import Prediction
 
 from .dataset import Dataset
-from .dataset import Reader
-from .dataset import Trainset
+from .reader import Reader
+from .trainset import Trainset
+from .builtin_datasets import get_dataset_dir
 from .evaluate import evaluate
 from .evaluate import print_perf
 from .evaluate import GridSearch
+from . import model_selection
 from . import dump
 
 __all__ = ['AlgoBase', 'NormalPredictor', 'BaselineOnly', 'KNNBasic',
            'KNNWithMeans', 'KNNBaseline', 'SVD', 'SVDpp', 'NMF', 'SlopeOne',
            'CoClustering', 'PredictionImpossible', 'Prediction', 'Dataset',
            'Reader', 'Trainset', 'evaluate', 'print_perf', 'GridSearch',
-           'dump', 'KNNWithZScore']
+           'dump', 'KNNWithZScore', 'get_dataset_dir', 'model_selection']
 
 __version__ = get_distribution('scikit-surprise').version
