@@ -102,7 +102,8 @@ class AlgoBase(object):
         The ``predict`` method converts raw ids to inner ids and then calls the
         ``estimate`` method which is defined in every derived class. If the
         prediction is impossible (e.g. because the user and/or the item is
-        unkown), the prediction is set to the global mean of all ratings.
+        unkown), the prediction is set according to :meth:`default_prediction()
+        <surprise.prediction_algorithms.algo_base.AlgoBase.default_prediction>`.
 
         Args:
             uid: (Raw) id of the user. See :ref:`this note<raw_inner_note>`.
@@ -151,7 +152,7 @@ class AlgoBase(object):
             details['was_impossible'] = False
 
         except PredictionImpossible as e:
-            est = self.trainset.global_mean
+            est = self.default_prediction()
             details['was_impossible'] = True
             details['reason'] = str(e)
 
@@ -172,6 +173,19 @@ class AlgoBase(object):
 
         return pred
 
+    def default_prediction(self):
+        '''Used when the ``PredictionImpossible`` exception is raised during a
+        call to :meth:`predict()
+        <surprise.prediction_algorithms.algo_base.AlgoBase.predict>`. By
+        default, return the global mean of all ratings (can be overridden in
+        child classes).
+
+        Returns:
+            (float): The mean of all ratings in the trainset.
+        '''
+
+        return self.trainset.global_mean
+
     def test(self, testset, verbose=False):
         """Test the algorithm on given testset, i.e. estimate all the ratings
         in the given testset.
@@ -226,7 +240,8 @@ class AlgoBase(object):
         method_name = self.bsl_options.get('method', 'als')
 
         try:
-            print('Estimating biases using', method_name + '...')
+            if self.verbose:
+                print('Estimating biases using', method_name + '...')
             self.bu, self.bi = method[method_name](self)
             return self.bu, self.bi
         except KeyError:
@@ -273,9 +288,11 @@ class AlgoBase(object):
             args += [self.trainset.global_mean, bx, by, shrinkage]
 
         try:
-            print('Computing the {0} similarity matrix...'.format(name))
+            if self.verbose:
+                print('Computing the {0} similarity matrix...'.format(name))
             sim = construction_func[name](*args)
-            print('Done computing similarity matrix.')
+            if self.verbose:
+                print('Done computing similarity matrix.')
             return sim
         except KeyError:
             raise NameError('Wrong sim name ' + name + '. Allowed values ' +
